@@ -6,7 +6,7 @@
 
 #include "connection.h"
 
-#include <KIOCore/KIO/TransferJob>
+#include <KIO/TransferJob>
 #include <QUrlQuery>
 
 #include "bugzilla_debug.h"
@@ -46,9 +46,7 @@ HTTPConnection::HTTPConnection(const QUrl &root, QObject *parent)
 {
 }
 
-HTTPConnection::~HTTPConnection()
-{
-}
+HTTPConnection::~HTTPConnection() = default;
 
 void HTTPConnection::setToken(const QString &authToken)
 {
